@@ -60,9 +60,9 @@ clintrials_gov_convert <- function(input, original, output,
   
   message(paste0("'",output, "' is created or modified\n"))
   #check against the output schema
-  check_out <- xml2::xml_validate(safety, schema_results)
+  check_out <- ( Sys.info()["sysname"]=="Windows") || xml2::xml_validate(safety, schema_results)
   if( !check_out){ warning(attr(check_out,"errors"))}
-  check_out <- xml2::xml_validate(original, schema_output)
+  check_out <-  xml2::xml_validate(original, schema_output)
   if( !check_out){ warning(attr(check_out,"errors"))}
 
   message("Please email cuh.cctu@nhs.net to tell us if you have successfully uploaded a study to ClinicalTrials.gov .\nThis is to allow us to measure the impact of this tool.")
